﻿//*****************************************************************************
// Description     : Declaration of functions and structure for controlling device
// Target Device   : APV8508, APV8104
// Target Platform : Windows, .NET Framework, C++
// Date            : August 2017
// Version         : 1.0
//*****************************************************************************
#ifndef __DEVICE_H__
#define __DEVICE_H__

#include "sys_compatible.h"
#include "sitcp.h"
#include "command.h"
#include "device_define.h"


//********** structure type definition ********************
// pair of command and parameter for configuring device
typedef struct {
    unsigned int    cmd_addr;      // command address
    unsigned short  value;         // parameter (16bit)
    short           reserve[2];    // (unused)
} DEVICE_CONFIG_LIST;

// alias structure for command communication
#define DEVICE_COM_INFO     SiTCPcom


//********** alias function *******************
#define device_connect      sitcp_connect
#define device_disconnect   sitcp_disconnect
#define device_write_16bit  sitcp_write_16bit
#define device_write_64bit  sitcp_write_64bit


//********** macro function *******************
// stop measurement
#define device_stop_measurement(pCmd)  \
            device_write_16bit(pCmd, DEVICE_COMMAND_AQS, DEVICE_PARAM_AQS_STOP)

// convert msec to count
#define device_msec2count(msec)     \
            (((unsigned qword)(msec) * 1000000UL) / (unsigned qword)(DEVICE_CNT_PER_NSEC))
// convert count to msec
#define device_count2msec(count)    \
            (((unsigned qword)(count) * (unsigned qword)(DEVICE_CNT_PER_NSEC)) / 1000000UL)


//********** prototype declaration **********
extern int device_write_3step(DEVICE_COM_INFO^, unsigned int);
extern int device_start_measurement(DEVICE_COM_INFO^);
extern int device_read_status(DEVICE_COM_INFO^,
                              unsigned short *, unsigned qword *,
                              unsigned int *, unsigned int *);
extern int device_read_histogram(DEVICE_COM_INFO^, char*, int, int, int);


#endif // __DEVICE_H__
