﻿//*****************************************************************************
// Description     : Definition of IO functions
// Target Device   : APV8508, APV8104
// Target Platform : Windows, .NET Framework, C++
// Date            : August 2017
// Version         : 1.0
//*****************************************************************************
#include "file.h"
#include "local_define.h"
using namespace System;
using namespace System::IO;


//#########################################################################
//  Name      : file_write_header
//  Function  : write header to the text file
//  Arguments :
//      in pName    : file name
//      in now_time : actual measurement time(msec)
//      in out_cnt  : pointer to the array of output count total
//      in out_cps  : pointer to the array of output count rate(cps)
//  Return :
//       0 : success
//      -1 : failed to open file
//#########################################################################
int file_write_header(String ^pName, unsigned int now_time,
                      unsigned int *out_cnt, unsigned int *out_cps)
{
    int i;

    try {
        // open file(create)
        StreamWriter ^writer = File::CreateText(pName);

        // write header information
        try {
            writer->WriteLine("[header]");
            writer->WriteLine("Real time(s), {0}", now_time/1000);

            writer->Write("Output count");
            for (i = 0; i < DEVICE_MAX_CHNUM; i++) {
                writer->Write(",{0}", *(out_cnt + i) );
            }
            writer->WriteLine();

            writer->Write("Output rate(cps)");
            for (i = 0; i < DEVICE_MAX_CHNUM; i++) {
                writer->Write(",{0}", *(out_cps + i) );
            }
            writer->WriteLine();
        }
        finally
        {
            if (writer) {
                delete (IDisposable^)writer;
            }
        }

    }
    catch (Exception ^e) {
        // failed to open file
        return(-1);
    }

    return(0);
}


//#########################################################################
//  Name      : file_write_data
//  Function  : write data to the text file
//  Arguments :
//      in pName : file name
//      in pBuff : array of data
//  Return :
//       0 : success
//      -1 : failed to open file
//#########################################################################
int file_write_data(String ^pName, unsigned int pBuff[][NUM_DATA])
{
    int i, j;

    try {
        // open file(append)
        StreamWriter ^writer = File::AppendText(pName);

        // write data
        try {
            writer->WriteLine("[data]");
            for (i = 0; i < NUM_DATA; i++) {
                writer->Write("{0}", pBuff[0][i]);      // CH1
				for (j = 1; j < DEVICE_MAX_CHNUM; j++) {
                    writer->Write(",{0}", pBuff[j][i]); // CH2-
				}
                writer->WriteLine();
            }
        }
        finally
        {
            if (writer) {
                delete (IDisposable^)writer;
            }
        }
    }
    catch (Exception ^e) {
        // failed to open file
        return(-1);
    }

    return(i);
}
